@@ -51,6 +51,12 @@ for (alt in c("two.sided", "greater", "less")) {
     expect_true(abs(test$p.value - test_02$p.value) < .01)
   })
 
+  if (alt == "two.sided") {
+    test_that("check contents", {
+      expect_true(test$statistic >= 0)
+    })
+  }
+
   # .0499 instead of .05 b/c of floating point error associated with convergence.
   CI1 <- test$conf.int[1] + .Machine$double.eps # Avoid boundary
   CI2 <- test$conf.int[2] - .Machine$double.eps
@@ -81,6 +87,12 @@ for (alt in c("two.sided", "greater")) {
     expect_true(abs(test$p.value - test_02$p.value) < .01)
   })
 
+  if (alt == "two.sided") {
+    test_that("check contents", {
+      expect_true(test$statistic >= 0)
+    })
+  }
+
   CI1 <- test$conf.int[1] + .Machine$double.eps # Avoid boundary
   CI2 <- test$conf.int[2] - .Machine$double.eps
   pval <- pmin(
@@ -109,6 +121,13 @@ for (alt in c("two.sided", "less")) {
     expect_true(test$p.value <= .05)
     expect_true(abs(test$p.value - test_02$p.value) < .01)
   })
+  rm(test_02)
+
+  if (alt == "two.sided") {
+    test_that("check contents", {
+      expect_true(test$statistic >= 0)
+    })
+  }
 
   CI1 <- test$conf.int[1] + .Machine$double.eps # Avoid boundary
   CI2 <- test$conf.int[2] - .Machine$double.eps
@@ -169,6 +188,12 @@ for (alt in c("two.sided", "greater", "less")) {
     expect_true(test$p.value > .05)
   })
 
+  if (alt == "two.sided") {
+    test_that("check contents", {
+      expect_true(test$statistic >= 0)
+    })
+  }
+
   # .0499 instead of .05 b/c of floating point error associated with convergence.
   CI1 <- test$conf.int[1] + .Machine$double.eps # Avoid boundary
   CI2 <- test$conf.int[2] - .Machine$double.eps
@@ -197,6 +222,12 @@ for (alt in c("two.sided", "greater")) {
     expect_true(test$p.value <= .05)
   })
 
+  if (alt == "two.sided") {
+    test_that("check contents", {
+      expect_true(test$statistic >= 0)
+    })
+  }
+
   CI1 <- test$conf.int[1] + .Machine$double.eps # Avoid boundary
   CI2 <- test$conf.int[2] - .Machine$double.eps
   pval <- pmin(
@@ -224,6 +255,12 @@ for (alt in c("two.sided", "less")) {
     expect_true(test$p.value <= .05)
   })
 
+  if (alt == "two.sided") {
+    test_that("check contents", {
+      expect_true(test$statistic >= 0)
+    })
+  }
+
   CI1 <- test$conf.int[1] + .Machine$double.eps # Avoid boundary
   CI2 <- test$conf.int[2] - .Machine$double.eps
   pval <- pmin(
@@ -282,6 +319,7 @@ test_that("Check structure.", {
 
 test_that("Check contents", {
   expect_true(test$p.value > .05)
+  expect_true(test$statistic >= 0)
 })
 
 # make sure CIs match
@@ -309,7 +347,8 @@ test_that("Check structure.", {
 })
 
 test_that("Check contents", {
-  expect_true(abs(test$p.value - test_02$p.value) < .02)
+  expect_true(test$p.value <= .05)
+  expect_true(test$statistic >= 0)
 })
 
 # make sure CIs match
@@ -367,6 +406,7 @@ test_that("Check structure.", {
 
 test_that("Check contents", {
   expect_true(test$p.value > .05)
+  expect_true(test$statistic >= 0)
 })
 
 # make sure CIs match
@@ -395,6 +435,7 @@ test_that("Check structure.", {
 
 test_that("Check contents", {
   expect_true(test$p.value < .05)
+  expect_true(test$statistic >= 0)
 })
 
 # make sure CIs match
